pub struct Token { /* private fields */ }Expand description
An extension providing a way to interact with a visitor’s CSRF token.
Implementations
Sourceimpl Token
impl Token
Sourcepub fn set(&self, identifier: impl Into<String>) -> Result<(), Error>
pub fn set(&self, identifier: impl Into<String>) -> Result<(), Error>
Updates the identifier used to sign the token. The value should only be valid for the duration of the user’s authenticated session and should be unique to that session.
See: OWASP’s CSRF Prevention Cheat Sheet.
Errors